@@ -3,7 +3,7 @@
   Copyright (C) 2016 Nikolaus Rath <Nikolaus@rath.org>
             (C) 2017 EditShare LLC <slawek.rudnicki@editshare.com>
 
-  This program can be distributed under the terms of the GNU GPL.
+  This program can be distributed under the terms of the GNU GPLv2.
   See the file COPYING.
  */
 
@@ -25,7 +25,7 @@
  * \include @file
  */
 
-#define FUSE_USE_VERSION 31
+#define FUSE_USE_VERSION 34
 
 #include <fuse.h>
 #include <fuse_lowlevel.h>  /* for fuse_cmdline_opts */
@@ -153,7 +153,7 @@ static int xmp_read(const char *path, char *buf, size_t size, off_t offset,
 	}
 }
 
-static struct fuse_operations xmp_oper = {
+static const struct fuse_operations xmp_oper = {
 		.init     = xmp_init,
 		.getattr  = xmp_getattr,
 		.readdir  = xmp_readdir,
@@ -212,6 +212,7 @@ int main(int argc, char *argv[]) {
 	struct fuse_args args = FUSE_ARGS_INIT(argc, argv);
 	struct fuse *fuse;
 	struct fuse_cmdline_opts opts;
+	struct fuse_loop_config config;
 	int res;
 
 	/* Initialize the files */
@@ -271,8 +272,11 @@ int main(int argc, char *argv[]) {
 
 	if (opts.singlethread)
 		res = fuse_loop(fuse);
-	else
-		res = fuse_loop_mt(fuse, opts.clone_fd);
+	else {
+		config.clone_fd = opts.clone_fd;
+		config.max_idle_threads = opts.max_idle_threads;
+		res = fuse_loop_mt(fuse, &config);
+	}
 	if (res)
 		res = 1;
 
